SparseColMat

Type Alias SparseColMat 

pub type SparseColMat<I, T, Rows = usize, Cols = usize> = SparseColMat<Own<I, T, Rows, Cols>>;
owning sparse column major matrix

see SymbolicSparseColMatRef

Aliased Type

#[repr(transparent)]
pub struct SparseColMat<I, T, Rows = usize, Cols = usize>(pub Own<I, T, Rows, Cols>);

Tuple Fields

0: Own<I, T, Rows, Cols>

Implementations

Source

impl<Rows: Shape, Cols: Shape, I: Index, T> SparseColMat<I, T, Rows, Cols>

pub fn new(symbolic: SymbolicSparseColMat<I, Rows, Cols>, val: Vec<T>) -> Self

pub fn parts(&self) -> (SymbolicSparseColMatRef<'_, I, Rows, Cols>, &[T])

pub fn parts_mut( &mut self, ) -> (SymbolicSparseColMatRef<'_, I, Rows, Cols>, &mut [T])

pub fn into_parts(self) -> (SymbolicSparseColMat<I, Rows, Cols>, Vec<T>)

pub fn symbolic(&self) -> SymbolicSparseColMatRef<'_, I, Rows, Cols>

pub fn val(&self) -> &[T]

pub fn val_mut(&mut self) -> &mut [T]

pub fn val_of_col(&self, j: Idx<Cols>) -> &[T]

pub fn val_of_col_mut(&mut self, j: Idx<Cols>) -> &mut [T]

pub fn as_shape<V: Shape, H: Shape>( &self, nrows: V, ncols: H, ) -> SparseColMatRef<'_, I, T, V, H>

pub fn as_shape_mut<V: Shape, H: Shape>( &mut self, nrows: V, ncols: H, ) -> SparseColMatMut<'_, I, T, V, H>

pub fn into_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SparseColMat<I, T, V, H>

pub fn as_dyn(&self) -> SparseColMatRef<'_, I, T>

pub fn as_dyn_mut(&mut self) -> SparseColMatMut<'_, I, T>

pub fn into_dyn(self) -> SparseColMat<I, T>

pub fn as_ref(&self) -> SparseColMatRef<'_, I, T, Rows, Cols>

pub fn transpose(&self) -> SparseRowMatRef<'_, I, T, Cols, Rows>

pub fn transpose_mut(&mut self) -> SparseRowMatMut<'_, I, T, Cols, Rows>

pub fn into_transpose(self) -> SparseRowMat<I, T, Cols, Rows>

pub fn conjugate(&self) -> SparseColMatRef<'_, I, T::Conj, Rows, Cols>
where T: Conjugate,

pub fn conjugate_mut(&mut self) -> SparseColMatMut<'_, I, T::Conj, Rows, Cols>
where T: Conjugate,

pub fn into_conjugate(self) -> SparseColMat<I, T::Conj, Rows, Cols>
where T: Conjugate,

pub fn adjoint(&self) -> SparseRowMatRef<'_, I, T::Conj, Cols, Rows>
where T: Conjugate,

pub fn adjoint_mut(&mut self) -> SparseRowMatMut<'_, I, T::Conj, Cols, Rows>
where T: Conjugate,

pub fn into_adjoint(self) -> SparseRowMat<I, T::Conj, Cols, Rows>
where T: Conjugate,

pub fn canonical(&self) -> SparseColMatRef<'_, I, T::Canonical, Rows, Cols>
where T: Conjugate,

pub fn canonical_mut( &mut self, ) -> SparseColMatMut<'_, I, T::Canonical, Rows, Cols>
where T: Conjugate,

pub fn into_canonical(self) -> SparseColMat<I, T::Canonical, Rows, Cols>
where T: Conjugate,

pub fn to_row_major( &self, ) -> Result<SparseRowMat<I, T::Canonical, Rows, Cols>, FaerError>
where T: Conjugate,

pub fn to_dense(&self) -> Mat<T::Canonical, Rows, Cols>
where T: Conjugate,

pub fn new_from_argsort( symbolic: SymbolicSparseColMat<I, Rows, Cols>, argsort: &Argsort<I>, val: &[T], ) -> Result<Self, FaerError>
where T: ComplexField,

create a new matrix from a previously created symbolic structure and value order

the provided values must correspond to the same indices that were provided in the function call from which the order was created

pub fn try_new_from_triplets( nrows: Rows, ncols: Cols, entries: &[Triplet<Idx<Rows, I>, Idx<Cols, I>, T>], ) -> Result<Self, CreationError>
where T: ComplexField,

create a new matrix from triplets

pub fn try_new_from_nonnegative_triplets( nrows: Rows, ncols: Cols, entries: &[Triplet<MaybeIdx<Rows, I>, MaybeIdx<Cols, I>, T>], ) -> Result<Self, CreationError>
where T: ComplexField,

create a new matrix from triplets

negative indices are ignored

pub fn get(&self, row: Idx<Rows>, col: Idx<Cols>) -> Option<&T>

pub fn get_mut(&mut self, row: Idx<Rows>, col: Idx<Cols>) -> Option<&mut T>

pub fn triplet_iter( &self, ) -> impl '_ + Iterator<Item = Triplet<Idx<Rows>, Idx<Cols>, &T>>

Methods from Deref<Target = SymbolicSparseColMat<I, Rows, Cols>>

pub fn nrows(&self) -> Rows

returns the number of rows of the matrix

pub fn ncols(&self) -> Cols

returns the number of columns of the matrix

pub fn shape(&self) -> (Rows, Cols)

returns the number of rows and columns of the matrix

pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>

returns a newly allocated matrix holding the values of self

pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>

returns a newly allocated matrix holding the values of self in row major format

pub fn compute_nnz(&self) -> usize

returns the number of non-zero elements in the matrix

pub fn col_ptr(&self) -> &'a [I]

returns the column pointers

pub fn col_nnz(&self) -> Option<&'a [I]>

returns the column non-zero counts

pub fn row_idx(&self) -> &'a [I]

returns the row indices

pub fn col_range(&self, j: Idx<Cols>) -> Range<usize>

returns the range specifying the indices of column j

pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>

returns the range specifying the indices of column j, without bound checks

pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &'a [Idx<Rows, I>]

returns the row indices of column j

pub fn row_idx_of_col( &self, j: Idx<Cols>, ) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>
where Rows: 'a, Cols: 'a,

returns the row indices of column j

pub fn parts(&self) -> (Rows, Cols, &[I], Option<&[I]>, &[I])

pub fn nrows(&self) -> Rows

returns the number of rows of the matrix

pub fn ncols(&self) -> Cols

returns the number of columns of the matrix

pub fn shape(&self) -> (Rows, Cols)

returns the number of rows and columns of the matrix

pub fn transpose(&self) -> SymbolicSparseRowMatRef<'_, I, Cols, Rows>

returns a view over the transpose of self

pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>

pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>

pub fn compute_nnz(&self) -> usize

pub fn col_ptr(&self) -> &[I]

pub fn col_nnz(&self) -> Option<&[I]>

pub fn row_idx(&self) -> &[I]

pub fn col_range(&self, j: Idx<Cols>) -> Range<usize>

pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>

pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &[Idx<Rows, I>]

pub fn row_idx_of_col( &self, j: Idx<Cols>, ) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>

pub fn as_shape<V: Shape, H: Shape>( &self, nrows: V, ncols: H, ) -> SymbolicSparseColMatRef<'_, I, V, H>

pub fn as_dyn(&self) -> SymbolicSparseColMatRef<'_, I>

pub fn as_ref(&self) -> SymbolicSparseColMatRef<'_, I, Rows, Cols>

Returns a view over the symbolic structure of self.