SparseColMatRef

Type Alias SparseColMatRef 

pub type SparseColMatRef<'a, I, T, Rows = usize, Cols = usize> = SparseColMat<Ref<'a, I, T, Rows, Cols>>;
view over sparse column major matrix

see SymbolicSparseColMatRef

Aliased Type

#[repr(transparent)]
pub struct SparseColMatRef<'a, I, T, Rows = usize, Cols = usize>(pub Ref<'a, I, T, Rows, Cols>);

Tuple Fields

0: Ref<'a, I, T, Rows, Cols>

Implementations

Source

impl<'a, Rows: Shape, Cols: Shape, I: Index, T> SparseColMatRef<'a, I, T, Rows, Cols>

pub fn new( symbolic: SymbolicSparseColMatRef<'a, I, Rows, Cols>, val: &'a [T], ) -> Self

creates a new sparse matrix view.

panics

panics if the length of values is not equal to the length of symbolic.row_idx()

pub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, Rows, Cols>, &'a [T])

returns the symbolic and numeric components of the sparse matrix

pub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, Rows, Cols>

returns the symbolic component of the sparse matrix

pub fn val(self) -> &'a [T]

returns the numeric component of the sparse matrix

pub fn val_of_col(self, j: Idx<Cols>) -> &'a [T]

returns a view over the values of column j

pub fn as_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SparseColMatRef<'a, I, T, V, H>

returns the input matrix with the given shape after checking that it matches the current shape

pub fn get(self, row: Idx<Rows>, col: Idx<Cols>) -> Option<&'a T>

returns a reference to the value at the given index, or None if the symbolic structure doesn’t contain it, or contains multiple indices with the given index

panics
  • panics if row >= self.nrows()
  • panics if col >= self.ncols()
pub fn as_dyn(self) -> SparseColMatRef<'a, I, T>

returns the input matrix with dynamic shape

pub fn as_ref(self) -> SparseColMatRef<'a, I, T, Rows, Cols>

returns a view over self

pub fn transpose(self) -> SparseRowMatRef<'a, I, T, Cols, Rows>

returns a view over the transpose of self

pub fn conjugate(self) -> SparseColMatRef<'a, I, T::Conj, Rows, Cols>
where T: Conjugate,

returns a view over the conjugate of self

pub fn adjoint(self) -> SparseRowMatRef<'a, I, T::Conj, Cols, Rows>
where T: Conjugate,

returns a view over the adjoint of self

pub fn canonical(self) -> SparseColMatRef<'a, I, T::Canonical, Rows, Cols>
where T: Conjugate,

returns an unconjugated view over self

pub fn to_row_major( &self, ) -> Result<SparseRowMat<I, T::Canonical, Rows, Cols>, FaerError>
where T: Conjugate,

returns a newly allocated matrix holding the (possibly conjugated) values of self in row major format

pub fn to_dense(&self) -> Mat<T::Canonical, Rows, Cols>
where T: Conjugate,

returns a newly allocated dense matrix holding the (possibly conjugated) values of self

pub fn triplet_iter( self, ) -> impl 'a + Iterator<Item = Triplet<Idx<Rows>, Idx<Cols>, &'a T>>
where Rows: 'a, Cols: 'a,

returns an iterator over the entries of the matrix.

Methods from Deref<Target = SymbolicSparseColMatRef<'a, I, Rows, Cols>>

pub fn nrows(&self) -> Rows

returns the number of rows of the matrix

pub fn ncols(&self) -> Cols

returns the number of columns of the matrix

pub fn shape(&self) -> (Rows, Cols)

returns the number of rows and columns of the matrix

pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>

returns a newly allocated matrix holding the values of self

pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>

returns a newly allocated matrix holding the values of self in row major format

pub fn compute_nnz(&self) -> usize

returns the number of non-zero elements in the matrix

pub fn col_ptr(&self) -> &'a [I]

returns the column pointers

pub fn col_nnz(&self) -> Option<&'a [I]>

returns the column non-zero counts

pub fn row_idx(&self) -> &'a [I]

returns the row indices

pub fn col_range(&self, j: Idx<Cols>) -> Range<usize>

returns the range specifying the indices of column j

pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>

returns the range specifying the indices of column j, without bound checks

pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &'a [Idx<Rows, I>]

returns the row indices of column j

pub fn row_idx_of_col( &self, j: Idx<Cols>, ) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>
where Rows: 'a, Cols: 'a,

returns the row indices of column j

pub fn parts(&self) -> (Rows, Cols, &[I], Option<&[I]>, &[I])

pub fn nrows(&self) -> Rows

returns the number of rows of the matrix

pub fn ncols(&self) -> Cols

returns the number of columns of the matrix

pub fn shape(&self) -> (Rows, Cols)

returns the number of rows and columns of the matrix

pub fn transpose(&self) -> SymbolicSparseRowMatRef<'_, I, Cols, Rows>

returns a view over the transpose of self

pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>

pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>

pub fn compute_nnz(&self) -> usize

pub fn col_ptr(&self) -> &[I]

pub fn col_nnz(&self) -> Option<&[I]>

pub fn row_idx(&self) -> &[I]

pub fn col_range(&self, j: Idx<Cols>) -> Range<usize>

pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>

pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &[Idx<Rows, I>]

pub fn row_idx_of_col( &self, j: Idx<Cols>, ) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>

pub fn as_shape<V: Shape, H: Shape>( &self, nrows: V, ncols: H, ) -> SymbolicSparseColMatRef<'_, I, V, H>

pub fn as_dyn(&self) -> SymbolicSparseColMatRef<'_, I>

pub fn as_ref(&self) -> SymbolicSparseColMatRef<'_, I, Rows, Cols>

Returns a view over the symbolic structure of self.