pub type SparseColMatRef<'a, I, T, Rows = usize, Cols = usize> = SparseColMat<Ref<'a, I, T, Rows, Cols>>;Expand description
view over sparse column major matrix
Aliased Type
#[repr(transparent)]pub struct SparseColMatRef<'a, I, T, Rows = usize, Cols = usize>(pub Ref<'a, I, T, Rows, Cols>);Tuple Fields
0: Ref<'a, I, T, Rows, Cols>Implementations
Sourceimpl<'a, Rows: Shape, Cols: Shape, I: Index, T> SparseColMatRef<'a, I, T, Rows, Cols>
impl<'a, Rows: Shape, Cols: Shape, I: Index, T> SparseColMatRef<'a, I, T, Rows, Cols>
Sourcepub fn new(
symbolic: SymbolicSparseColMatRef<'a, I, Rows, Cols>,
val: &'a [T],
) -> Self
pub fn new( symbolic: SymbolicSparseColMatRef<'a, I, Rows, Cols>, val: &'a [T], ) -> Self
creates a new sparse matrix view.
panics
panics if the length of values is not equal to the length of
symbolic.row_idx()
Sourcepub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, Rows, Cols>, &'a [T])
pub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, Rows, Cols>, &'a [T])
returns the symbolic and numeric components of the sparse matrix
Sourcepub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, Rows, Cols>
pub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, Rows, Cols>
returns the symbolic component of the sparse matrix
Sourcepub fn val_of_col(self, j: Idx<Cols>) -> &'a [T]
pub fn val_of_col(self, j: Idx<Cols>) -> &'a [T]
returns a view over the values of column j
Sourcepub fn as_shape<V: Shape, H: Shape>(
self,
nrows: V,
ncols: H,
) -> SparseColMatRef<'a, I, T, V, H>
pub fn as_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SparseColMatRef<'a, I, T, V, H>
returns the input matrix with the given shape after checking that it matches the current shape
Sourcepub fn get(self, row: Idx<Rows>, col: Idx<Cols>) -> Option<&'a T>
pub fn get(self, row: Idx<Rows>, col: Idx<Cols>) -> Option<&'a T>
returns a reference to the value at the given index, or None if the symbolic structure
doesn’t contain it, or contains multiple indices with the given index
panics
- panics if
row >= self.nrows() - panics if
col >= self.ncols()
Sourcepub fn as_dyn(self) -> SparseColMatRef<'a, I, T>
pub fn as_dyn(self) -> SparseColMatRef<'a, I, T>
returns the input matrix with dynamic shape
Sourcepub fn as_ref(self) -> SparseColMatRef<'a, I, T, Rows, Cols>
pub fn as_ref(self) -> SparseColMatRef<'a, I, T, Rows, Cols>
returns a view over self
Sourcepub fn transpose(self) -> SparseRowMatRef<'a, I, T, Cols, Rows>
pub fn transpose(self) -> SparseRowMatRef<'a, I, T, Cols, Rows>
returns a view over the transpose of self
Sourcepub fn conjugate(self) -> SparseColMatRef<'a, I, T::Conj, Rows, Cols>where
T: Conjugate,
pub fn conjugate(self) -> SparseColMatRef<'a, I, T::Conj, Rows, Cols>where
T: Conjugate,
returns a view over the conjugate of self
Sourcepub fn adjoint(self) -> SparseRowMatRef<'a, I, T::Conj, Cols, Rows>where
T: Conjugate,
pub fn adjoint(self) -> SparseRowMatRef<'a, I, T::Conj, Cols, Rows>where
T: Conjugate,
returns a view over the adjoint of self
Sourcepub fn canonical(self) -> SparseColMatRef<'a, I, T::Canonical, Rows, Cols>where
T: Conjugate,
pub fn canonical(self) -> SparseColMatRef<'a, I, T::Canonical, Rows, Cols>where
T: Conjugate,
returns an unconjugated view over self
Sourcepub fn to_row_major(
&self,
) -> Result<SparseRowMat<I, T::Canonical, Rows, Cols>, FaerError>where
T: Conjugate,
pub fn to_row_major(
&self,
) -> Result<SparseRowMat<I, T::Canonical, Rows, Cols>, FaerError>where
T: Conjugate,
returns a newly allocated matrix holding the (possibly conjugated) values of self in row
major format
Methods from Deref<Target = SymbolicSparseColMatRef<'a, I, Rows, Cols>>
Sourcepub fn shape(&self) -> (Rows, Cols)
pub fn shape(&self) -> (Rows, Cols)
returns the number of rows and columns of the matrix
Sourcepub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
returns a newly allocated matrix holding the values of self
Sourcepub fn to_row_major(
&self,
) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
returns a newly allocated matrix holding the values of self in row major format
Sourcepub fn compute_nnz(&self) -> usize
pub fn compute_nnz(&self) -> usize
returns the number of non-zero elements in the matrix
Sourcepub fn col_range(&self, j: Idx<Cols>) -> Range<usize>
pub fn col_range(&self, j: Idx<Cols>) -> Range<usize>
returns the range specifying the indices of column j
Sourcepub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>
pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>
returns the range specifying the indices of column j, without bound checks
Sourcepub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &'a [Idx<Rows, I>] ⓘ
pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &'a [Idx<Rows, I>] ⓘ
returns the row indices of column j
Sourcepub fn row_idx_of_col(
&self,
j: Idx<Cols>,
) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>where
Rows: 'a,
Cols: 'a,
pub fn row_idx_of_col(
&self,
j: Idx<Cols>,
) -> impl 'a + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>where
Rows: 'a,
Cols: 'a,
returns the row indices of column j
Sourcepub fn shape(&self) -> (Rows, Cols)
pub fn shape(&self) -> (Rows, Cols)
returns the number of rows and columns of the matrix
Sourcepub fn transpose(&self) -> SymbolicSparseRowMatRef<'_, I, Cols, Rows>
pub fn transpose(&self) -> SymbolicSparseRowMatRef<'_, I, Cols, Rows>
returns a view over the transpose of self
Sourcepub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
pub fn to_owned(&self) -> Result<SymbolicSparseColMat<I, Rows, Cols>, FaerError>
Sourcepub fn to_row_major(
&self,
) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
pub fn to_row_major( &self, ) -> Result<SymbolicSparseRowMat<I, Rows, Cols>, FaerError>
Sourcepub fn compute_nnz(&self) -> usize
pub fn compute_nnz(&self) -> usize
Sourcepub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>
pub unsafe fn col_range_unchecked(&self, j: Idx<Cols>) -> Range<usize>
Sourcepub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &[Idx<Rows, I>] ⓘ
pub fn row_idx_of_col_raw(&self, j: Idx<Cols>) -> &[Idx<Rows, I>] ⓘ
Sourcepub fn row_idx_of_col(
&self,
j: Idx<Cols>,
) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>
pub fn row_idx_of_col( &self, j: Idx<Cols>, ) -> impl '_ + Clone + ExactSizeIterator + DoubleEndedIterator<Item = Idx<Rows>>
Sourcepub fn as_shape<V: Shape, H: Shape>(
&self,
nrows: V,
ncols: H,
) -> SymbolicSparseColMatRef<'_, I, V, H>
pub fn as_shape<V: Shape, H: Shape>( &self, nrows: V, ncols: H, ) -> SymbolicSparseColMatRef<'_, I, V, H>
Sourcepub fn as_dyn(&self) -> SymbolicSparseColMatRef<'_, I>
pub fn as_dyn(&self) -> SymbolicSparseColMatRef<'_, I>
Sourcepub fn as_ref(&self) -> SymbolicSparseColMatRef<'_, I, Rows, Cols>
pub fn as_ref(&self) -> SymbolicSparseColMatRef<'_, I, Rows, Cols>
Returns a view over the symbolic structure of self.